@@ -1,3 +1,16 @@
+//! The pre-commit binary
+
+#![warn(
+    rust_2018_idioms,
+    unused,
+    rust_2021_compatibility,
+    nonstandard_style,
+    future_incompatible,
+    missing_copy_implementations,
+    missing_debug_implementations,
+    missing_docs
+)]
+
 use std::{convert::TryFrom, env, io::stdout};
 
 use miette::{IntoDiagnostic, Result};
